
import * as React from 'react';

interface IconProps extends React.SVGAttributes<SVGElement> {
  children?: never;
  color?: string;
}

/**
 * @name DocumentPlusIcon
 * * @alias AddIcon
 *
 * @category solid
 *
 * @description
 * El ícono DocumentPlus representa la acción de agregar un nuevo documento. Visualmente, muestra un documento con un símbolo de más (+).
 *
 * 
 * @usage
 * - Botones para permitir a los usuarios agregar nuevos registros.
 * - Enlaces para destacar la opción de agregar contenido.
 * - Formularios donde se necesite la acción de crear nuevos registros.
 *
 * @accessibility
 * Asegurarse de incluir un atributo `aria-label` o `aria-hidden="true"` si el ícono es decorativo.
 *
 * @returns {JSX.Element} Componente SVG.
 */
const DocumentPlusIcon = React.forwardRef<SVGSVGElement, IconProps>(
  ({ color = 'currentColor', ...props }, forwardedRef) => {
    return (
      <svg {...props} ref={forwardedRef} xmlns="http://www.w3.org/2000/svg" aria-hidden="true" data-slot="icon" viewBox="0 0 24 24" fill="currentColor"><path fillRule="evenodd" d="M5.625 1.5H9a3.75 3.75 0 0 1 3.75 3.75v1.875c0 1.036.84 1.875 1.875 1.875H16.5a3.75 3.75 0 0 1 3.75 3.75v7.875c0 1.035-.84 1.875-1.875 1.875H5.625a1.875 1.875 0 0 1-1.875-1.875V3.375c0-1.036.84-1.875 1.875-1.875ZM12.75 12a.75.75 0 0 0-1.5 0v2.25H9a.75.75 0 0 0 0 1.5h2.25V18a.75.75 0 0 0 1.5 0v-2.25H15a.75.75 0 0 0 0-1.5h-2.25V12Z" clipRule="evenodd"/><path d="M14.25 5.25a5.23 5.23 0 0 0-1.279-3.434 9.768 9.768 0 0 1 6.963 6.963A5.23 5.23 0 0 0 16.5 7.5h-1.875a.375.375 0 0 1-.375-.375V5.25Z"/></svg>
    );
  }
);

DocumentPlusIcon.displayName = 'DocumentPlusIcon';

export { DocumentPlusIcon, DocumentPlusIcon as AddIcon };
